---
title: "ITAR"
description: "Terraform compliance scanning for ITAR — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Agency" variant="danger" />
<Badge text="Government" variant="tip" />

**Issuing body:** [DDTC](https://www.pmddtc.state.gov)
**Jurisdiction:** Country — North America
**Countries:** US


## Assessment

Assess your infrastructure against ITAR for free at any tier:

```bash
complyform assess --frameworks=itar
```

## Remediation

Requires Agency tier or higher ($4,999/yr) for remediation.

```bash
complyform remediate --frameworks=itar
```

## Related Frameworks

- [HIPAA](/frameworks/hipaa)
- [NIST 800-53 Rev. 5](/frameworks/nist_800_53)
- [CCPA / CPRA](/frameworks/ccpa)
- [PHIPA](/frameworks/phipa)
- [SOX IT Controls](/frameworks/sox_it)
- [FedRAMP](/frameworks/fedramp)
- [CMMC](/frameworks/cmmc)
- [CJIS](/frameworks/cjis)
- [FISMA](/frameworks/fisma)
- [NERC CIP](/frameworks/nerc_cip)
- [TX-RAMP](/frameworks/tx_ramp)
- [StateRAMP](/frameworks/stateramp)
- [GLBA](/frameworks/glba)
- [FERPA](/frameworks/ferpa)
